@@ -1,11 +1,8 @@
-from __future__ import unicode_literals
-
 import os
 import shutil
-import pytest
-
 from unittest import mock
 
+import pytest
 from click.testing import CliRunner
 
 from great_expectations import DataContext
@@ -30,17 +27,21 @@ def test_cli_init_on_existing_project_with_no_uncommitted_dirs_answering_yes_to_
     root_dir = tmp_path_factory.mktemp("hiya")
     root_dir = str(root_dir)
     os.makedirs(os.path.join(root_dir, "data"))
+    data_folder_path = os.path.join(root_dir, "data")
     data_path = os.path.join(root_dir, "data", "Titanic.csv")
     fixture_path = file_relative_path(
         __file__, os.path.join("..", "test_sets", "Titanic.csv")
     )
     shutil.copy(fixture_path, data_path)
 
+    # Create a new project from scratch that we will use for the test in the next step
+
     runner = CliRunner(mix_stderr=False)
     result = runner.invoke(
         cli,
         ["init", "-d", root_dir],
-        input="Y\n1\n1\n{}\n\n\n\n".format(data_path, catch_exceptions=False),
+        input="\n\n1\n1\n{}\n\n\n\n2\n{}\n\n\n\n".format(data_folder_path, data_path),
+        catch_exceptions=False,
     )
     stdout = result.output
     assert result.exit_code == 0
@@ -61,7 +62,9 @@ def test_cli_init_on_existing_project_with_no_uncommitted_dirs_answering_yes_to_
 
     # Test the second invocation of init
     runner = CliRunner(mix_stderr=False)
-    with pytest.warns(UserWarning, match="Warning. An existing `great_expectations.yml` was found"):
+    with pytest.warns(
+        UserWarning, match="Warning. An existing `great_expectations.yml` was found"
+    ):
         result = runner.invoke(
             cli, ["init", "-d", root_dir], input="Y\nn\n", catch_exceptions=False
         )
@@ -98,17 +101,22 @@ def test_cli_init_on_complete_existing_project_all_uncommitted_dirs_exist(
     root_dir = tmp_path_factory.mktemp("hiya")
     root_dir = str(root_dir)
     os.makedirs(os.path.join(root_dir, "data"))
+    data_folder_path = os.path.join(root_dir, "data")
     data_path = os.path.join(root_dir, "data", "Titanic.csv")
     fixture_path = file_relative_path(
         __file__, os.path.join("..", "test_sets", "Titanic.csv")
     )
     shutil.copy(fixture_path, data_path)
 
+    # Create a new project from scratch that we will use for the test in the next step
+
     runner = CliRunner(mix_stderr=False)
     result = runner.invoke(
         cli,
         ["init", "-d", root_dir],
-        input="Y\n1\n1\n{}\n\n\n\n".format(data_path, catch_exceptions=False),
+        input="\n\n1\n1\n{}\n\n\n\n2\n{}\n\n\n\n".format(
+            data_folder_path, data_path, catch_exceptions=False
+        ),
     )
     assert result.exit_code == 0
     assert mock_webbrowser.call_count == 1
@@ -119,8 +127,12 @@ def test_cli_init_on_complete_existing_project_all_uncommitted_dirs_exist(
         in mock_webbrowser.call_args[0][0]
     )
 
+    # Now the test begins - rerun the init on an existing project
+
     runner = CliRunner(mix_stderr=False)
-    with pytest.warns(UserWarning, match="Warning. An existing `great_expectations.yml` was found"):
+    with pytest.warns(
+        UserWarning, match="Warning. An existing `great_expectations.yml` was found"
+    ):
         result = runner.invoke(
             cli, ["init", "-d", root_dir], input="n\n", catch_exceptions=False
         )
@@ -147,7 +159,7 @@ def test_cli_init_connection_string_non_working_db_connection_instructs_user_and
     result = runner.invoke(
         cli,
         ["init"],
-        input="Y\n2\n5\nmy_db\nsqlite:////not_a_real.db\nn\n",
+        input="\n\n2\n6\nmy_db\nsqlite:////not_a_real.db\n\nn\n",
         catch_exceptions=False,
     )
     stdout = result.output
@@ -157,7 +169,7 @@ def test_cli_init_connection_string_non_working_db_connection_instructs_user_and
     assert "What data would you like Great Expectations to connect to" in stdout
     assert "Which database backend are you using" in stdout
     assert "What is the url/connection string for the sqlalchemy connection" in stdout
-    assert "Give your new data source a short name" in stdout
+    assert "Give your new Datasource a short name" in stdout
     assert "Attempting to connect to your database. This may take a moment" in stdout
     assert "Cannot connect to the database" in stdout
 
@@ -199,6 +211,7 @@ def test_cli_init_connection_string_non_working_db_connection_instructs_user_and
 great_expectations/
     .gitignore
     great_expectations.yml
+    checkpoints/
     expectations/
     notebooks/
         pandas/
