@@ -1,7 +1,6 @@
-import pytest
 import os
 
-from six import PY2
+import pytest
 
 import great_expectations as ge
 from great_expectations.core.util import nested_update
@@ -9,8 +8,14 @@ from great_expectations.util import lint_code
 
 
 def test_validate_non_dataset(file_data_asset, empty_expectation_suite):
-    with pytest.raises(ValueError, match=r"The validate util method only supports dataset validations"):
-        ge.validate(file_data_asset, empty_expectation_suite, data_asset_class=ge.data_asset.FileDataAsset)
+    with pytest.raises(
+        ValueError, match=r"The validate util method only supports dataset validations"
+    ):
+        ge.validate(
+            file_data_asset,
+            empty_expectation_suite,
+            data_asset_class=ge.data_asset.FileDataAsset,
+        )
 
 
 def test_validate_dataset(dataset, basic_expectation_suite):
@@ -18,55 +23,92 @@ def test_validate_dataset(dataset, basic_expectation_suite):
     assert res.success is True
     assert res["statistics"]["evaluated_expectations"] == 4
     if isinstance(dataset, ge.dataset.PandasDataset):
-        res = ge.validate(dataset,
-                          expectation_suite=basic_expectation_suite,  data_asset_class=ge.dataset.PandasDataset)
+        res = ge.validate(
+            dataset,
+            expectation_suite=basic_expectation_suite,
+            data_asset_class=ge.dataset.PandasDataset,
+        )
         assert res.success is True
         assert res["statistics"]["evaluated_expectations"] == 4
-        with pytest.raises(ValueError, match=r"The validate util method only supports validation for subtypes of the provided data_asset_type"):
-            ge.validate(dataset, basic_expectation_suite,  data_asset_class=ge.dataset.SqlAlchemyDataset)
+        with pytest.raises(
+            ValueError,
+            match=r"The validate util method only supports validation for subtypes of the provided data_asset_type",
+        ):
+            ge.validate(
+                dataset,
+                basic_expectation_suite,
+                data_asset_class=ge.dataset.SqlAlchemyDataset,
+            )
 
     elif isinstance(dataset, ge.dataset.SqlAlchemyDataset):
-        res = ge.validate(dataset,
-                          expectation_suite=basic_expectation_suite,  data_asset_class=ge.dataset.SqlAlchemyDataset)
+        res = ge.validate(
+            dataset,
+            expectation_suite=basic_expectation_suite,
+            data_asset_class=ge.dataset.SqlAlchemyDataset,
+        )
         assert res.success is True
         assert res["statistics"]["evaluated_expectations"] == 4
-        with pytest.raises(ValueError, match=r"The validate util method only supports validation for subtypes of the provided data_asset_type"):
-            ge.validate(dataset,
-                        expectation_suite=basic_expectation_suite,  data_asset_class=ge.dataset.PandasDataset)
+        with pytest.raises(
+            ValueError,
+            match=r"The validate util method only supports validation for subtypes of the provided data_asset_type",
+        ):
+            ge.validate(
+                dataset,
+                expectation_suite=basic_expectation_suite,
+                data_asset_class=ge.dataset.PandasDataset,
+            )
 
     elif isinstance(dataset, ge.dataset.SparkDFDataset):
-        res = ge.validate(dataset, basic_expectation_suite, data_asset_class=ge.dataset.SparkDFDataset)
+        res = ge.validate(
+            dataset, basic_expectation_suite, data_asset_class=ge.dataset.SparkDFDataset
+        )
         assert res.success is True
         assert res["statistics"]["evaluated_expectations"] == 4
-        with pytest.raises(ValueError, match=r"The validate util method only supports validation for subtypes of the provided data_asset_type"):
-            ge.validate(dataset,
-                        expectation_suite=basic_expectation_suite,  data_asset_class=ge.dataset.PandasDataset)
+        with pytest.raises(
+            ValueError,
+            match=r"The validate util method only supports validation for subtypes of the provided data_asset_type",
+        ):
+            ge.validate(
+                dataset,
+                expectation_suite=basic_expectation_suite,
+                data_asset_class=ge.dataset.PandasDataset,
+            )
 
 
-def test_validate_using_data_context(dataset, data_context):
+def test_validate_using_data_context(
+    dataset, data_context_parameterized_expectation_suite
+):
     # Before running, the data context should not have compiled parameters
-    assert data_context._evaluation_parameter_dependencies_compiled is False
+    assert (
+        data_context_parameterized_expectation_suite._evaluation_parameter_dependencies_compiled
+        is False
+    )
     res = ge.validate(
         dataset,
         expectation_suite_name="my_dag_node.default",
-        data_context=data_context
+        data_context=data_context_parameterized_expectation_suite,
     )
 
     # Since the handling of evaluation parameters is no longer happening without an action,
     # the context should still be not compiles after validation.
-    assert data_context._evaluation_parameter_dependencies_compiled is False
+    assert (
+        data_context_parameterized_expectation_suite._evaluation_parameter_dependencies_compiled
+        is False
+    )
 
     # And, we should have validated the right number of expectations from the context-provided config
     assert res.success is False
     assert res.statistics["evaluated_expectations"] == 2
 
 
-def test_validate_using_data_context_path(dataset, data_context):
-    data_context_path = data_context.root_directory
+def test_validate_using_data_context_path(
+    dataset, data_context_parameterized_expectation_suite
+):
+    data_context_path = data_context_parameterized_expectation_suite.root_directory
     res = ge.validate(
         dataset,
         expectation_suite_name="my_dag_node.default",
-        data_context=data_context_path
+        data_context=data_context_path,
     )
 
     # We should have now found the right suite with expectations to evaluate
@@ -74,31 +116,39 @@ def test_validate_using_data_context_path(dataset, data_context):
     assert res["statistics"]["evaluated_expectations"] == 2
 
 
-def test_validate_invalid_parameters(dataset, basic_expectation_suite, data_context):
-    with pytest.raises(ValueError, match="Either an expectation suite or a DataContext is required for validation."):
+def test_validate_invalid_parameters(
+    dataset, basic_expectation_suite, data_context_parameterized_expectation_suite
+):
+    with pytest.raises(
+        ValueError,
+        match="Either an expectation suite or a DataContext is required for validation.",
+    ):
         ge.validate(dataset)
 
 
 def test_gen_directory_tree_str(tmp_path_factory):
     project_dir = str(tmp_path_factory.mktemp("project_dir"))
     os.mkdir(os.path.join(project_dir, "BBB"))
-    with open(os.path.join(project_dir, "BBB", "bbb.txt"), 'w') as f:
+    with open(os.path.join(project_dir, "BBB", "bbb.txt"), "w") as f:
         f.write("hello")
-    with open(os.path.join(project_dir, "BBB", "aaa.txt"), 'w') as f:
+    with open(os.path.join(project_dir, "BBB", "aaa.txt"), "w") as f:
         f.write("hello")
 
     os.mkdir(os.path.join(project_dir, "AAA"))
 
     print(ge.util.gen_directory_tree_str(project_dir))
 
-    #Note: files and directories are sorteds alphabetically, so that this method can be used for testing.
-    assert ge.util.gen_directory_tree_str(project_dir) == """\
+    # Note: files and directories are sorteds alphabetically, so that this method can be used for testing.
+    assert (
+        ge.util.gen_directory_tree_str(project_dir)
+        == """\
 project_dir0/
     AAA/
     BBB/
         aaa.txt
         bbb.txt
 """
+    )
 
 
 def test_nested_update():
@@ -106,9 +156,7 @@ def test_nested_update():
     batch_kwargs = {
         "path": "/a/path",
         "reader_method": "read_csv",
-        "reader_options": {
-            "header": 0
-        }
+        "reader_options": {"header": 0},
     }
 
     nested_update(batch_kwargs, {"reader_options": {"nrows": 1}})
@@ -116,28 +164,21 @@ def test_nested_update():
     assert batch_kwargs == {
         "path": "/a/path",
         "reader_method": "read_csv",
-        "reader_options": {
-            "header": 0,
-            "nrows": 1
-        }
+        "reader_options": {"header": 0, "nrows": 1},
     }
 
 
 def test_nested_update_lists():
     # nested_update is useful for update nested dictionaries (such as batch_kwargs with reader_options as a dictionary)
     dependencies = {
-        "suite.warning": {
-            "metric.name": ["column=foo"]
-        },
-        "suite.failure": {
-            "metric.blarg": [""]
-        }
+        "suite.warning": {"metric.name": ["column=foo"]},
+        "suite.failure": {"metric.blarg": [""]},
     }
 
     new_dependencies = {
         "suite.warning": {
             "metric.other_name": ["column=foo"],
-            "metric.name": ["column=bar"]
+            "metric.name": ["column=bar"],
         }
     }
 
@@ -146,11 +187,9 @@ def test_nested_update_lists():
     assert dependencies == {
         "suite.warning": {
             "metric.name": ["column=foo", "column=bar"],
-            "metric.other_name": ["column=foo"]
+            "metric.other_name": ["column=foo"],
         },
-        "suite.failure": {
-            "metric.blarg": [""]
-        }
+        "suite.failure": {"metric.blarg": [""]},
     }
 
 
