@@ -1,5 +1,3 @@
-from __future__ import division
-
 import copy
 import importlib
 import locale
@@ -17,11 +15,7 @@ from great_expectations.core import (
     ExpectationSuiteValidationResultSchema,
     ExpectationValidationResultSchema,
 )
-from great_expectations.dataset import (
-    PandasDataset,
-    SparkDFDataset,
-    SqlAlchemyDataset,
-)
+from great_expectations.dataset import PandasDataset, SparkDFDataset, SqlAlchemyDataset
 from great_expectations.profile import ColumnsExistProfiler
 
 expectationValidationResultSchema = ExpectationValidationResultSchema()
@@ -29,6 +23,7 @@ expectationSuiteValidationResultSchema = ExpectationSuiteValidationResultSchema(
 
 try:
     import sqlalchemy.dialects.sqlite as sqlitetypes
+
     SQLITE_TYPES = {
         "VARCHAR": sqlitetypes.VARCHAR,
         "CHAR": sqlitetypes.CHAR,
@@ -38,13 +33,14 @@ try:
         "DATE": sqlitetypes.DATE,
         "FLOAT": sqlitetypes.FLOAT,
         "BOOLEAN": sqlitetypes.BOOLEAN,
-        "TIMESTAMP": sqlitetypes.TIMESTAMP
+        "TIMESTAMP": sqlitetypes.TIMESTAMP,
     }
 except ImportError:
     SQLITE_TYPES = {}
 
 try:
     import sqlalchemy.dialects.postgresql as postgresqltypes
+
     POSTGRESQL_TYPES = {
         "TEXT": postgresqltypes.TEXT,
         "CHAR": postgresqltypes.CHAR,
@@ -55,13 +51,14 @@ try:
         "DATE": postgresqltypes.DATE,
         "DOUBLE_PRECISION": postgresqltypes.DOUBLE_PRECISION,
         "BOOLEAN": postgresqltypes.BOOLEAN,
-        "NUMERIC": postgresqltypes.NUMERIC
+        "NUMERIC": postgresqltypes.NUMERIC,
     }
 except ImportError:
     POSTGRESQL_TYPES = {}
 
 try:
     import sqlalchemy.dialects.mysql as mysqltypes
+
     MYSQL_TYPES = {
         "TEXT": mysqltypes.TEXT,
         "CHAR": mysqltypes.CHAR,
@@ -72,7 +69,7 @@ try:
         "TIMESTAMP": mysqltypes.TIMESTAMP,
         "DATE": mysqltypes.DATE,
         "FLOAT": mysqltypes.FLOAT,
-        "BOOLEAN": mysqltypes.BOOLEAN
+        "BOOLEAN": mysqltypes.BOOLEAN,
     }
 except ImportError:
     MYSQL_TYPES = {}
@@ -85,8 +82,8 @@ def modify_locale(func):
         print(old_locale)
         # old_locale = locale.getlocale(locale.LC_TIME) Why not getlocale? not sure
         try:
-            new_locale = locale.setlocale(locale.LC_TIME, 'en_US.UTF-8')
-            assert new_locale == 'en_US.UTF-8'
+            new_locale = locale.setlocale(locale.LC_TIME, "en_US.UTF-8")
+            assert new_locale == "en_US.UTF-8"
             func(*args, **kwargs)
         except Exception:
             raise
@@ -109,8 +106,8 @@ def assertDeepAlmostEqual(expected, actual, *args, **kwargs):
     precision).
 
     """
-    is_root = '__trace' not in kwargs
-    trace = kwargs.pop('__trace', 'ROOT')
+    is_root = "__trace" not in kwargs
+    trace = kwargs.pop("__trace", "ROOT")
     try:
         # if isinstance(expected, (int, float, long, complex)):
         if isinstance(expected, (int, float, complex)):
@@ -119,28 +116,30 @@ def assertDeepAlmostEqual(expected, actual, *args, **kwargs):
             assert len(expected) == len(actual)
             for index in range(len(expected)):
                 v1, v2 = expected[index], actual[index]
-                assertDeepAlmostEqual(v1, v2,
-                                      __trace=repr(index), *args, **kwargs)
+                assertDeepAlmostEqual(v1, v2, __trace=repr(index), *args, **kwargs)
         elif isinstance(expected, dict):
             assert set(expected) == set(actual)
             for key in expected:
-                assertDeepAlmostEqual(expected[key], actual[key],
-                                      __trace=repr(key), *args, **kwargs)
+                assertDeepAlmostEqual(
+                    expected[key], actual[key], __trace=repr(key), *args, **kwargs
+                )
         else:
             assert expected == actual
     except AssertionError as exc:
-        exc.__dict__.setdefault('traces', []).append(trace)
+        exc.__dict__.setdefault("traces", []).append(trace)
         if is_root:
-            trace = ' -> '.join(reversed(exc.traces))
+            trace = " -> ".join(reversed(exc.traces))
             exc = AssertionError("%s\nTRACE: %s" % (str(exc), trace))
         raise exc
 
 
-def get_dataset(dataset_type, data, schemas=None, profiler=ColumnsExistProfiler, caching=True):
+def get_dataset(
+    dataset_type, data, schemas=None, profiler=ColumnsExistProfiler, caching=True
+):
     """Utility to create datasets for json-formatted tests.
     """
     df = pd.DataFrame(data)
-    if dataset_type == 'PandasDataset':
+    if dataset_type == "PandasDataset":
         if schemas and "pandas" in schemas:
             schema = schemas["pandas"]
             pandas_schema = {}
@@ -168,79 +167,108 @@ def get_dataset(dataset_type, data, schemas=None, profiler=ColumnsExistProfiler,
 
     elif dataset_type == "sqlite":
         from sqlalchemy import create_engine
-        engine = create_engine('sqlite://')
+
+        engine = create_engine("sqlite://")
         conn = engine.connect()
         # Add the data to the database as a new table
 
         sql_dtypes = {}
-        if schemas and "sqlite" in schemas and isinstance(engine.dialect, sqlitetypes.dialect):
+        if (
+            schemas
+            and "sqlite" in schemas
+            and isinstance(engine.dialect, sqlitetypes.dialect)
+        ):
             schema = schemas["sqlite"]
-            sql_dtypes = {col: SQLITE_TYPES[dtype] for (col,dtype) in schema.items()}
+            sql_dtypes = {col: SQLITE_TYPES[dtype] for (col, dtype) in schema.items()}
             for col in schema:
                 type_ = schema[col]
                 if type_ in ["INTEGER", "SMALLINT", "BIGINT"]:
-                    df[col] = pd.to_numeric(df[col], downcast='signed')
+                    df[col] = pd.to_numeric(df[col], downcast="signed")
                 elif type_ in ["FLOAT", "DOUBLE", "DOUBLE_PRECISION"]:
                     df[col] = pd.to_numeric(df[col])
                 elif type_ in ["DATETIME", "TIMESTAMP"]:
                     df[col] = pd.to_datetime(df[col])
 
-        tablename = "test_data_" + ''.join([random.choice(string.ascii_letters + string.digits) for n in range(8)])
+        tablename = "test_data_" + "".join(
+            [random.choice(string.ascii_letters + string.digits) for n in range(8)]
+        )
         df.to_sql(name=tablename, con=conn, index=False, dtype=sql_dtypes)
 
         # Build a SqlAlchemyDataset using that database
-        return SqlAlchemyDataset(tablename, engine=conn, profiler=profiler, caching=caching)
+        return SqlAlchemyDataset(
+            tablename, engine=conn, profiler=profiler, caching=caching
+        )
 
-    elif dataset_type == 'postgresql':
+    elif dataset_type == "postgresql":
         from sqlalchemy import create_engine
+
         # Create a new database
-        engine = create_engine('postgresql://postgres@localhost/test_ci')
+        engine = create_engine("postgresql://postgres@localhost/test_ci")
         conn = engine.connect()
 
         sql_dtypes = {}
-        if schemas and "postgresql" in schemas and isinstance(engine.dialect, postgresqltypes.dialect):
+        if (
+            schemas
+            and "postgresql" in schemas
+            and isinstance(engine.dialect, postgresqltypes.dialect)
+        ):
             schema = schemas["postgresql"]
-            sql_dtypes = {col: POSTGRESQL_TYPES[dtype] for (col, dtype) in schema.items()}
+            sql_dtypes = {
+                col: POSTGRESQL_TYPES[dtype] for (col, dtype) in schema.items()
+            }
             for col in schema:
                 type_ = schema[col]
                 if type_ in ["INTEGER", "SMALLINT", "BIGINT"]:
-                    df[col] = pd.to_numeric(df[col], downcast='signed')
+                    df[col] = pd.to_numeric(df[col], downcast="signed")
                 elif type_ in ["FLOAT", "DOUBLE", "DOUBLE_PRECISION"]:
                     df[col] = pd.to_numeric(df[col])
                 elif type_ in ["DATETIME", "TIMESTAMP"]:
                     df[col] = pd.to_datetime(df[col])
 
-        tablename = "test_data_" + ''.join([random.choice(string.ascii_letters + string.digits) for n in range(8)])
+        tablename = "test_data_" + "".join(
+            [random.choice(string.ascii_letters + string.digits) for n in range(8)]
+        )
         df.to_sql(name=tablename, con=conn, index=False, dtype=sql_dtypes)
 
         # Build a SqlAlchemyDataset using that database
-        return SqlAlchemyDataset(tablename, engine=conn, profiler=profiler, caching=caching)
+        return SqlAlchemyDataset(
+            tablename, engine=conn, profiler=profiler, caching=caching
+        )
 
-    elif dataset_type == 'mysql':
+    elif dataset_type == "mysql":
         from sqlalchemy import create_engine
-        engine = create_engine('mysql://root@localhost/test_ci')
+
+        engine = create_engine("mysql://root@localhost/test_ci")
         conn = engine.connect()
 
         sql_dtypes = {}
-        if schemas and "mysql" in schemas and isinstance(engine.dialect, mysqltypes.dialect):
+        if (
+            schemas
+            and "mysql" in schemas
+            and isinstance(engine.dialect, mysqltypes.dialect)
+        ):
             schema = schemas["mysql"]
             sql_dtypes = {col: MYSQL_TYPES[dtype] for (col, dtype) in schema.items()}
             for col in schema:
                 type_ = schema[col]
                 if type_ in ["INTEGER", "SMALLINT", "BIGINT"]:
-                    df[col] = pd.to_numeric(df[col], downcast='signed')
+                    df[col] = pd.to_numeric(df[col], downcast="signed")
                 elif type_ in ["FLOAT", "DOUBLE", "DOUBLE_PRECISION"]:
                     df[col] = pd.to_numeric(df[col])
                 elif type_ in ["DATETIME", "TIMESTAMP"]:
                     df[col] = pd.to_datetime(df[col])
 
-        tablename = "test_data_" + ''.join([random.choice(string.ascii_letters + string.digits) for n in range(8)])
+        tablename = "test_data_" + "".join(
+            [random.choice(string.ascii_letters + string.digits) for n in range(8)]
+        )
         df.to_sql(name=tablename, con=conn, index=False, dtype=sql_dtypes)
 
         # Build a SqlAlchemyDataset using that database
-        return SqlAlchemyDataset(tablename, engine=conn, profiler=profiler, caching=caching)
+        return SqlAlchemyDataset(
+            tablename, engine=conn, profiler=profiler, caching=caching
+        )
 
-    elif dataset_type == 'SparkDFDataset':
+    elif dataset_type == "SparkDFDataset":
         from pyspark.sql import SparkSession
         import pyspark.sql.types as sparktypes
 
@@ -254,21 +282,27 @@ def get_dataset(dataset_type, data, schemas=None, profiler=ColumnsExistProfiler,
             "DoubleType": sparktypes.DoubleType,
             "BooleanType": sparktypes.BooleanType,
             "DataType": sparktypes.DataType,
-            "NullType": sparktypes.NullType
+            "NullType": sparktypes.NullType,
         }
 
         spark = SparkSession.builder.getOrCreate()
         # We need to allow null values in some column types that do not support them natively, so we skip
         # use of df in this case.
-        data_reshaped = list(zip(*[v for _, v in data.items()]))  # create a list of rows
-        if schemas and 'spark' in schemas:
-            schema = schemas['spark']
+        data_reshaped = list(
+            zip(*[v for _, v in data.items()])
+        )  # create a list of rows
+        if schemas and "spark" in schemas:
+            schema = schemas["spark"]
             # sometimes first method causes Spark to throw a TypeError
             try:
-                spark_schema = sparktypes.StructType([
-                    sparktypes.StructField(column, SPARK_TYPES[schema[column]](), True)
-                    for column in schema
-                ])
+                spark_schema = sparktypes.StructType(
+                    [
+                        sparktypes.StructField(
+                            column, SPARK_TYPES[schema[column]](), True
+                        )
+                        for column in schema
+                    ]
+                )
                 # We create these every time, which is painful for testing
                 # However nuance around null treatment as well as the desire
                 # for real datetime support in tests makes this necessary
@@ -304,23 +338,31 @@ def get_dataset(dataset_type, data, schemas=None, profiler=ColumnsExistProfiler,
                                 vals.append(parse(val))
                         data[col] = vals
                 # Do this again, now that we have done type conversion using the provided schema
-                data_reshaped = list(zip(*[v for _, v in data.items()]))  # create a list of rows
+                data_reshaped = list(
+                    zip(*[v for _, v in data.items()])
+                )  # create a list of rows
                 spark_df = spark.createDataFrame(data_reshaped, schema=spark_schema)
             except TypeError:
-                string_schema = sparktypes.StructType([
-                    sparktypes.StructField(column, sparktypes.StringType())
-                    for column in schema
-                ])
+                string_schema = sparktypes.StructType(
+                    [
+                        sparktypes.StructField(column, sparktypes.StringType())
+                        for column in schema
+                    ]
+                )
                 spark_df = spark.createDataFrame(data_reshaped, string_schema)
                 for c in spark_df.columns:
-                    spark_df = spark_df.withColumn(c, spark_df[c].cast(SPARK_TYPES[schema[c]]()))
+                    spark_df = spark_df.withColumn(
+                        c, spark_df[c].cast(SPARK_TYPES[schema[c]]())
+                    )
         elif len(data_reshaped) == 0:
             # if we have an empty dataset and no schema, need to assign an arbitrary type
             columns = list(data.keys())
-            spark_schema = sparktypes.StructType([
-                sparktypes.StructField(column, sparktypes.StringType())
-                for column in columns
-            ])
+            spark_schema = sparktypes.StructType(
+                [
+                    sparktypes.StructField(column, sparktypes.StringType())
+                    for column in columns
+                ]
+            )
             spark_df = spark.createDataFrame(data_reshaped, spark_schema)
         else:
             # if no schema provided, uses Spark's schema inference
@@ -334,15 +376,10 @@ def get_dataset(dataset_type, data, schemas=None, profiler=ColumnsExistProfiler,
 
 def candidate_getter_is_on_temporary_notimplemented_list(context, getter):
     if context in ["sqlite"]:
-        return getter in [
-            'get_column_modes',
-            'get_column_stdev'
-        ]
+        return getter in ["get_column_modes", "get_column_stdev"]
     if context in ["postgresql", "mysql"]:
-        return getter in [
-            'get_column_modes'
-        ]
-    if context == 'SparkDFDataset':
+        return getter in ["get_column_modes"]
+    if context == "SparkDFDataset":
         return getter in []
 
 
@@ -393,7 +430,7 @@ def candidate_test_is_on_temporary_notimplemented_list(context, expectation_type
             "expect_column_pair_values_to_be_equal",
             "expect_column_pair_values_A_to_be_greater_than_B",
             "expect_column_pair_values_to_be_in_set",
-            "expect_multicolumn_values_to_be_unique"
+            "expect_multicolumn_values_to_be_unique",
         ]
     if context == "SparkDFDataset":
         return expectation_type in [
@@ -423,7 +460,7 @@ def candidate_test_is_on_temporary_notimplemented_list(context, expectation_type
             # "expect_column_values_to_match_strftime_format",
             "expect_column_values_to_be_dateutil_parseable",
             "expect_column_values_to_be_json_parseable",
-            "expect_column_values_to_match_json_schema",
+            # "expect_column_values_to_match_json_schema",
             # "expect_column_mean_to_be_between",
             # "expect_column_median_to_be_between",
             # "expect_column_quantile_values_to_be_between",
@@ -439,9 +476,9 @@ def candidate_test_is_on_temporary_notimplemented_list(context, expectation_type
             # "expect_column_kl_divergence_to_be_less_than",
             "expect_column_parameterized_distribution_ks_test_p_value_to_be_greater_than",
             # "expect_column_pair_values_to_be_equal",
-            "expect_column_pair_values_A_to_be_greater_than_B",
+            # "expect_column_pair_values_A_to_be_greater_than_B",
             "expect_column_pair_values_to_be_in_set",
-            "expect_multicolumn_values_to_be_unique"
+            # "expect_multicolumn_values_to_be_unique",
         ]
     return False
 
@@ -470,75 +507,86 @@ def evaluate_json_test(data_asset, expectation_type, test):
     :return: None. asserts correctness of results.
     """
 
-    data_asset.set_default_expectation_argument('result_format', 'COMPLETE')
-    data_asset.set_default_expectation_argument('include_config', False)
+    data_asset.set_default_expectation_argument("result_format", "COMPLETE")
+    data_asset.set_default_expectation_argument("include_config", False)
 
-    if 'title' not in test:
-        raise ValueError(
-            "Invalid test configuration detected: 'title' is required.")
+    if "title" not in test:
+        raise ValueError("Invalid test configuration detected: 'title' is required.")
 
-    if 'exact_match_out' not in test:
+    if "exact_match_out" not in test:
         raise ValueError(
-            "Invalid test configuration detected: 'exact_match_out' is required.")
+            "Invalid test configuration detected: 'exact_match_out' is required."
+        )
 
-    if 'in' not in test:
-        raise ValueError(
-            "Invalid test configuration detected: 'in' is required.")
+    if "in" not in test:
+        raise ValueError("Invalid test configuration detected: 'in' is required.")
 
-    if 'out' not in test:
-        raise ValueError(
-            "Invalid test configuration detected: 'out' is required.")
+    if "out" not in test:
+        raise ValueError("Invalid test configuration detected: 'out' is required.")
 
     # Support tests with positional arguments
-    if isinstance(test['in'], list):
-        result = getattr(data_asset, expectation_type)(*test['in'])
+    if isinstance(test["in"], list):
+        result = getattr(data_asset, expectation_type)(*test["in"])
     # As well as keyword arguments
     else:
-        result = getattr(data_asset, expectation_type)(**test['in'])
+        result = getattr(data_asset, expectation_type)(**test["in"])
 
     # Check results
-    if test['exact_match_out'] is True:
-        assert expectationValidationResultSchema.load(test['out']) == result
+    if test["exact_match_out"] is True:
+        assert expectationValidationResultSchema.load(test["out"]) == result
     else:
         # Convert result to json since our tests are reading from json so cannot easily contain richer types (e.g. NaN)
         # NOTE - 20191031 - JPC - we may eventually want to change these tests as we update our view on how
         # representations, serializations, and objects should interact and how much of that is shown to the user.
         result = result.to_json_dict()
-        for key, value in test['out'].items():
+        for key, value in test["out"].items():
             # Apply our great expectations-specific test logic
 
-            if key == 'success':
-                assert result['success'] == value
+            if key == "success":
+                assert result["success"] == value
 
-            elif key == 'observed_value':
-                if 'tolerance' in test:
+            elif key == "observed_value":
+                if "tolerance" in test:
                     if isinstance(value, dict):
-                        assert set(value.keys()) == set(result["result"]["observed_value"].keys())
+                        assert set(value.keys()) == set(
+                            result["result"]["observed_value"].keys()
+                        )
                         for k, v in value.items():
-                            assert np.allclose(result["result"]["observed_value"][k], v, rtol=test["tolerance"])
+                            assert np.allclose(
+                                result["result"]["observed_value"][k],
+                                v,
+                                rtol=test["tolerance"],
+                            )
                     else:
-                        assert np.allclose(result['result']['observed_value'], value, rtol=test['tolerance'])
+                        assert np.allclose(
+                            result["result"]["observed_value"],
+                            value,
+                            rtol=test["tolerance"],
+                        )
                 else:
-                    assert value == result['result']['observed_value']
+                    assert value == result["result"]["observed_value"]
 
             # NOTE: This is a key used ONLY for testing cases where an expectation is legitimately allowed to return
             # any of multiple possible observed_values. expect_column_values_to_be_of_type is one such expectation.
             elif key == "observed_value_list":
                 assert result["result"]["observed_value"] in value
 
-            elif key == 'unexpected_index_list':
+            elif key == "unexpected_index_list":
                 if isinstance(data_asset, (SqlAlchemyDataset, SparkDFDataset)):
                     pass
                 else:
-                    assert result['result']['unexpected_index_list'] == value
+                    assert result["result"]["unexpected_index_list"] == value
 
-            elif key == 'unexpected_list':
-                assert result['result']['unexpected_list'] == value, "expected " + \
-                    str(value) + " but got " + \
-                    str(result['result']['unexpected_list'])
+            elif key == "unexpected_list":
+                assert result["result"]["unexpected_list"] == value, (
+                    "expected "
+                    + str(value)
+                    + " but got "
+                    + str(result["result"]["unexpected_list"])
+                )
 
-            elif key == 'details':
-                assert result['result']['details'] == value
+            elif key == "details":
+                assert result["result"]["details"] == value
 
             elif key == "value_counts":
                 for val_count in value:
@@ -547,55 +595,85 @@ def evaluate_json_test(data_asset, expectation_type, test):
             elif key.startswith("observed_cdf"):
                 if "x_-1" in key:
                     if key.endswith("gt"):
-                        assert result["result"]["details"]["observed_cdf"]["x"][-1] > value
+                        assert (
+                            result["result"]["details"]["observed_cdf"]["x"][-1] > value
+                        )
                     else:
-                        assert result["result"]["details"]["observed_cdf"]["x"][-1] == value
+                        assert (
+                            result["result"]["details"]["observed_cdf"]["x"][-1]
+                            == value
+                        )
                 elif "x_0" in key:
                     if key.endswith("lt"):
-                        assert result["result"]["details"]["observed_cdf"]["x"][0] < value
+                        assert (
+                            result["result"]["details"]["observed_cdf"]["x"][0] < value
+                        )
                     else:
-                        assert result["result"]["details"]["observed_cdf"]["x"][0] == value
+                        assert (
+                            result["result"]["details"]["observed_cdf"]["x"][0] == value
+                        )
                 else:
                     raise ValueError(
-                        "Invalid test specification: unknown key " + key + " in 'out'")
+                        "Invalid test specification: unknown key " + key + " in 'out'"
+                    )
 
-            elif key == 'traceback_substring':
-                assert result['exception_info']['raised_exception']
-                assert value in result['exception_info']['exception_traceback'], "expected to find " + \
-                    value + " in " + \
-                    result['exception_info']['exception_traceback']
+            elif key == "traceback_substring":
+                assert result["exception_info"]["raised_exception"]
+                assert value in result["exception_info"]["exception_traceback"], (
+                    "expected to find "
+                    + value
+                    + " in "
+                    + result["exception_info"]["exception_traceback"]
+                )
 
             elif key == "expected_partition":
-                assert np.allclose(result["result"]["details"]["expected_partition"]["bins"], value["bins"])
-                assert np.allclose(result["result"]["details"]["expected_partition"]["weights"], value["weights"])
+                assert np.allclose(
+                    result["result"]["details"]["expected_partition"]["bins"],
+                    value["bins"],
+                )
+                assert np.allclose(
+                    result["result"]["details"]["expected_partition"]["weights"],
+                    value["weights"],
+                )
                 if "tail_weights" in result["result"]["details"]["expected_partition"]:
-                    assert np.allclose(result["result"]["details"]["expected_partition"]["tail_weights"], value["tail_weights"])
+                    assert np.allclose(
+                        result["result"]["details"]["expected_partition"][
+                            "tail_weights"
+                        ],
+                        value["tail_weights"],
+                    )
 
             elif key == "observed_partition":
-                assert np.allclose(result["result"]["details"]["observed_partition"]["bins"], value["bins"])
-                assert np.allclose(result["result"]["details"]["observed_partition"]["weights"], value["weights"])
+                assert np.allclose(
+                    result["result"]["details"]["observed_partition"]["bins"],
+                    value["bins"],
+                )
+                assert np.allclose(
+                    result["result"]["details"]["observed_partition"]["weights"],
+                    value["weights"],
+                )
                 if "tail_weights" in result["result"]["details"]["observed_partition"]:
-                    assert np.allclose(result["result"]["details"]["observed_partition"]["tail_weights"], value["tail_weights"])
+                    assert np.allclose(
+                        result["result"]["details"]["observed_partition"][
+                            "tail_weights"
+                        ],
+                        value["tail_weights"],
+                    )
 
             else:
                 raise ValueError(
-                    "Invalid test specification: unknown key " + key + " in 'out'")
+                    "Invalid test specification: unknown key " + key + " in 'out'"
+                )
 
 
 def is_library_installed(library_name):
     """
     Tests if a library is installed.
     """
-    # Gross legacy python 2 hacks
-    try:
-        ModuleNotFoundError
-    except NameError:
-        ModuleNotFoundError = ImportError
-
     try:
         importlib.import_module(library_name)
         return True
-    except ModuleNotFoundError as e:
+    except ModuleNotFoundError:
         return False
 
 
@@ -605,4 +683,3 @@ def safe_remove(path):
             os.remove(path)
         except OSError as e:
             print(e)
-            pass
\ No newline at end of file
